@@ -61,7 +61,7 @@ pns_labeller <- function(data_pns, dictionary.file) {
                   "P02001", "P01601", "P018", "P02002", "P023", "P02501", "P02602",
                   "P02801", "P029", "P03202", "P035", "P03701", "P03702", "P03904",
                   "P03905", "P03906", "P04001", "P04101", "P04102", "P042", "P04301",
-                  "P04302", "P04401", "P04405", "P04406", "P05402", "P05403",
+                  "P04302", "P04401", "P04405", "P04406", "P053", "P05402", "P05403",
                   "P05405", "P05406", "P05408", "P05409", "P05411", "P05412",
                   "P05414", "P05415", "P05417", "P05418", "P05421", "P05422",
                   "P05601", "P05602", "P05603", "P05604", "P05605", "P057", "P5701",
